CodeMirror: N-Triples mode

## N-Triples mode

The N-Triples mode also works well with on N-Quad documents.

<http://Sub1> <http://pred1> <http://obj> . <http://Sub2> <http://pred2#an2> "literal 1" . <http://Sub3#an3> <http://pred3> _:bnode3 . _:bnode4 <http://pred4> "literal 2"@lang . _:bnode5 <http://pred5> "literal 3"^^<http://type> .

MIME types defined: `application/n-triples`.

N-Quads add a fourth element to the statement to track which graph the statement is from. Otherwise, it's identical to N-Triples.

<http://Sub1> <http://pred1> <http://obj> <http://graph3> . <http://Sub2> <http://pred2#an2> "literal 1" <http://graph2> . <http://Sub3#an3> <http://pred3> _:bnode3 <http://graph2> . _:bnode4 <http://pred4> "literal 2"@lang <http://graph2> . # if a graph label _:bnode5 <http://pred5> "literal 3"^^<http://type> .

MIME types defined: `application/n-quads`.